==> secioss-idsuite-cloud-sp-3.0.1-x86_64.tgz: secioss-idsuite-cloud-sp-3.0.1-x86_64/src/lism/get_editlist_json.php <==
<?php
require_once('config.php');

header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past

if (file_exists(LISM))
{
    $lismxml = simplexml_load_file(LISM); 
}
else 
{
    echo('ファイルが開けません。: '. LISM);
    exit(1);
}

$system = $_GET["system"];

$editlist = array();
$checked_master = array();
foreach ($lismxml->sync->data as $v)
{
    $system_ele = (string)$v->attributes()->name;
    if ($system_ele == $system)
    {
        //削除
        foreach ($v->object->syncattr as $vv)
        {
            $checked_master[] = strtolower((string)$vv->name);
        }
    }
}
//data部分の処理：追加、更新
foreach ($lismxml->data as $v)
{
    $system_ele = (string)$v->attributes()->name;
    if ($system_ele == $system)
    {
        foreach ($v->storage->object as $vv)
        {
            if ((string)$vv->attributes()->name == 'User')
            {
                foreach ($vv->attr as $vvv)
                {
                    $master = (string)$vvv->attributes()->name;
                    $field = (String)$vvv->column;
                    if ($master == 'uid' || in_array($master, $checked_master)) 
                    {
                        $checked = true;
                    }
                    else 
                    {
                        $checked = false;
                    }
                    if (!empty($field)) 
                    {
                        $editlist[] = array("checked" => $checked
                            ,   "master"    =>  $master
                            ,   "field"     =>  $field
                        );
                    }
                }
            }
        }
    }
}

echo json_encode($editlist);
?>

==> secioss-idsuite-cloud-sp-3.0.2-x86_64.tgz: secioss-idsuite-cloud-sp-3.0.2-x86_64/src/lism/get_editlist_json.php <==
<?php
require_once('config.php');

header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past

if (file_exists(LISM))
{
    $lismxml = simplexml_load_file(LISM); 
}
else 
{
    echo('ファイルが開けません。: '. LISM);
    exit(1);
}

$system = $_GET["system"];

$editlist = array();
$checked_master = array();
foreach ($lismxml->sync->data as $v)
{
    $system_elt = (string)$v->attributes()->name;
    if ($system_elt == $system || $system_elt == 'IDP')
    {
        //削除
        foreach ($v->object->syncattr as $vv)
        {
            $checked_master[] = strtolower((string)$vv->name);
        }
    }
}
//data部分の処理：追加、更新
foreach ($lismxml->data as $v)
{
    $system_elt = (string)$v->attributes()->name;
    if ($system_elt == $system)
    {
        foreach ($v->storage->object as $vv)
        {
            if ((string)$vv->attributes()->name == 'User')
            {
                foreach ($vv->attr as $vvv)
                {
                    $master = (string)$vvv->attributes()->name;
                    $field = (String)$vvv->column;
                    if ($master == 'uid' || in_array($master, $checked_master)) 
                    {
                        $checked = true;
                    }
                    else 
                    {
                        $checked = false;
                    }
                    if (!empty($field)) 
                    {
                        $editlist[] = array("checked" => $checked
                            ,   "master"    =>  $master
                            ,   "field"     =>  $field
                        );
                    }
                }
            }
        }
    }
}

echo json_encode($editlist);
?>
